@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-from journalism.columns import TextColumn, IntColumn, FloatColumn
+from journalism.columns import TextColumn, IntColumn, DecimalColumn
 from journalism.exceptions import *
 from journalism.table import Table
 
